@@ -26,9 +26,11 @@ namespace Analitza
 {
 
 /**
- *	This class represents the string expression writer.
+ * \class StringExpressionWriter
+ * 
+ * \ingroup AnalitzaModule
  *
- *	@author Aleix Pol <aleixpol@kde.org>  
+ * \brief This class represents the string expression writer.
  */
 
 class StringExpressionWriter : public ExpressionWriter
@@ -42,6 +44,8 @@ class StringExpressionWriter : public ExpressionWriter
 		virtual QString accept(const Operator* var);
 		virtual QString accept(const Vector* var);
 		virtual QString accept(const List* l);
+		virtual QString accept(const Matrix* m);
+		virtual QString accept(const MatrixRow* mr);
 		virtual QString accept(const Apply* a);
 		virtual QString accept(const CustomObject* c);
 		
